@@ -5,22 +5,17 @@ import fmu.ensemble
 from webviz_config.common_cache import CACHE
 from webviz_config.webviz_store import webvizstore
 
-from .fmu_input import scratch_ensemble
+from .fmu_input import load_ensemble_set
 
 
 @CACHE.memoize(timeout=CACHE.TIMEOUT)
 @webvizstore
-def extract_mismatch(ens_paths, observation_file: Path) -> pd.DataFrame:
+def extract_mismatch(ens_paths: dict, observation_file: Path) -> pd.DataFrame:
     """Convert the fmu-ensemble mismatch dataframe into the the format
     suitable for the interactive history match visualization.
     """
 
-    list_ens = [
-        scratch_ensemble(ensemble_name, path)
-        for (ensemble_name, path) in ens_paths.items()
-    ]
-
-    ens_data = fmu.ensemble.EnsembleSet("HistoryMatch", list_ens)
+    ens_data = load_ensemble_set(ens_paths)
 
     df_mismatch = fmu.ensemble.Observations(str(observation_file)).mismatch(ens_data)
 
