@@ -49,6 +49,8 @@ from ._subsurface_map import SubsurfaceMap
 from ._surface_viewer_fmu import SurfaceViewerFMU
 from ._surface_with_grid_cross_section import SurfaceWithGridCrossSection
 from ._surface_with_seismic_cross_section import SurfaceWithSeismicCrossSection
+from ._structural_uncertainty import StructuralUncertainty
 from ._well_cross_section import WellCrossSection
 from ._well_cross_section_fmu import WellCrossSectionFMU
 from ._assisted_history_matching_analysis import AssistedHistoryMatchingAnalysis
+from ._well_completions import WellCompletions
