@@ -8,6 +8,7 @@ from webviz_config.webviz_assets import WEBVIZ_ASSETS
 
 import webviz_subsurface
 from webviz_subsurface._models import EnsembleSetModel
+from webviz_subsurface._models import caching_ensemble_set_model_factory
 from .views import main_view
 from .models import ParametersModel, SimulationTimeSeriesModel
 from .controllers import (
@@ -97,11 +98,15 @@ slow for large models.
         self.csvfile_smry = csvfile_smry
 
         if ensembles is not None:
-            self.emodel = EnsembleSetModel(
-                ensemble_paths={
-                    ens: webviz_settings.shared_settings["scratch_ensembles"][ens]
-                    for ens in ensembles
-                }
+            self.emodel: EnsembleSetModel = (
+                caching_ensemble_set_model_factory.get_or_create_model(
+                    ensemble_paths={
+                        ens: webviz_settings.shared_settings["scratch_ensembles"][ens]
+                        for ens in ensembles
+                    },
+                    time_index=self.time_index,
+                    column_keys=self.column_keys,
+                )
             )
             self.pmodel = ParametersModel(
                 dataframe=self.emodel.load_parameters(),
@@ -109,10 +114,7 @@ slow for large models.
                 drop_constants=drop_constants,
             )
             self.vmodel = SimulationTimeSeriesModel(
-                dataframe=self.emodel.load_smry(
-                    time_index=self.time_index, column_keys=self.column_keys
-                ),
-                theme=self.theme,
+                dataframe=self.emodel.get_or_load_smry_cached()
             )
 
         elif self.csvfile_parameters is None:
@@ -125,7 +127,7 @@ slow for large models.
             )
             if self.csvfile_smry is not None:
                 self.vmodel = SimulationTimeSeriesModel(
-                    dataframe=read_csv(csvfile_smry), theme=self.theme.plotly_theme
+                    dataframe=read_csv(csvfile_smry)
                 )
             else:
                 self.vmodel = None
@@ -134,19 +136,29 @@ slow for large models.
 
     @property
     def layout(self) -> dcc.Tabs:
-        return main_view(parent=self)
+        return main_view(
+            get_uuid=self.uuid,
+            vectormodel=self.vmodel,
+            parametermodel=self.pmodel,
+            theme=self.theme,
+        )
 
     def set_callbacks(self, app) -> None:
-        parameter_qc_controller(self, app)
+        parameter_qc_controller(app=app, get_uuid=self.uuid, parametermodel=self.pmodel)
         if self.vmodel is not None:
-            parameter_response_controller(self, app)
+            parameter_response_controller(
+                app=app,
+                get_uuid=self.uuid,
+                parametermodel=self.pmodel,
+                vectormodel=self.vmodel,
+            )
 
     def add_webvizstore(self):
         store = []
         if self.ensembles is not None:
             store.extend(self.emodel.webvizstore)
         else:
-            store.extend(
+            store.append(
                 (
                     read_csv,
                     [
@@ -155,7 +167,7 @@ slow for large models.
                 )
             )
             if self.csvfile_smry is not None:
-                store.extend(
+                store.append(
                     (
                         read_csv,
                         [
